exceptiontools.LilyPondParserError
==================================

.. inheritance-diagram:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.LilyPondParserError.LilyPondParserError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
